@@ -11,6 +11,9 @@ from findmydevice.models import Device
 logger = logging.getLogger(__name__)
 
 
+ACCESS_TOKEN_LENGTH = 12
+
+
 def _make_cache_key(token):
     cache_key = f'access_token_{token}'
     logger.debug('Cache key: %r', cache_key)
@@ -34,8 +37,8 @@ def get_device_by_token(token):
 
 
 def new_access_token(device: Device):
-    token = get_random_string(length=12)
+    token = get_random_string(length=ACCESS_TOKEN_LENGTH)
     timeout = settings.FMD_ACCESS_TOKEN_TIMEOUT_SEC
     cache.set(key=_make_cache_key(token), value=device.uuid, timeout=timeout)
-    logger.info('Store access token %r for %s (timeout: %i sec)', token, device.uuid, timeout)
+    logger.info('Store access token %r for %s (timeout: %i sec)', token, device, timeout)
     return token
