@@ -1,6 +1,6 @@
 import logging
 
-from django.http import JsonResponse
+from django.http import HttpResponse, JsonResponse
 from django.views import View
 
 from findmydevice.json_utils import parse_json
@@ -35,10 +35,10 @@ class DeviceView(View):
             pubkey=data['pubkey'],
             user_agent=user_agent,
         )
-        access_token = {'DeviceId': device.uuid, 'AccessToken': ''}
+        access_token = {'DeviceId': device.short_id, 'AccessToken': ''}
         return JsonResponse(access_token)
 
-    def post(self, request, *args, **kwargs):
+    def post(self, request):
         """
         Delete a device
         """
@@ -49,4 +49,4 @@ class DeviceView(View):
         logger.info('Delete device: %s', device)
         info = device.delete()
         logger.info('Delete info: %s', info)
-        return JsonResponse(data={})
+        return HttpResponse(content=b'')
