@@ -2,7 +2,7 @@ import logging
 import time
 
 from django.conf import settings
-from django.http import JsonResponse
+from django.http import HttpResponse, JsonResponse
 from django.views import View
 
 from findmydevice.json_utils import parse_json
@@ -67,10 +67,8 @@ class LocationView(View):
                 user_agent=user_agent,
             )
             logger.info('New location stored: %s', location)
-        response_data = {
-            # TODO
-        }
-        return JsonResponse(response_data)
+
+        return HttpResponse(content=b'')
 
     def put(self, request):
         """
