@@ -5,7 +5,7 @@ from django.views import View
 
 from findmydevice.json_utils import parse_json
 from findmydevice.models import Location
-from findmydevice.models.device import get_device_by_token
+from findmydevice.services.device import get_device_by_token
 
 
 logger = logging.getLogger(__name__)
