@@ -149,7 +149,7 @@ USE_TZ = True
 # _____________________________________________________________________________
 # Static files (CSS, JavaScript, Images)
 
-STATIC_URL = '/static/'
+STATIC_URL = '/static/'  # Can't change! https://gitlab.com/jedie/django-find-my-device/-/issues/7
 STATIC_ROOT = str(__Path(BASE_PATH, 'static'))
 
 MEDIA_URL = '/media/'
